@@ -1,5 +1,5 @@
-/**
- * Copyright (C) 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+/*
+ * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -16,11 +16,11 @@
 
 #include <QObject>
 
-#include "kgpgtransaction.h"
+#include "kgpgeditkeytransaction.h"
 
 class QString;
 
-class KGpgAddPhoto: public KGpgTransaction {
+class KGpgAddPhoto: public KGpgEditKeyTransaction {
 	Q_OBJECT
 
 public:
