@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -16,12 +16,12 @@
 
 #include <QObject>
 
-#include "kgpgtransaction.h"
+#include "kgpgeditkeytransaction.h"
 
 /**
- * \brief enable of disable a key
+ * @brief enable of disable a key
  */
-class KGpgChangeDisable: public KGpgTransaction {
+class KGpgChangeDisable: public KGpgEditKeyTransaction {
 	Q_OBJECT
 
 public:
@@ -31,10 +31,8 @@ public:
 	void setDisable(const bool &disable);
 
 protected:
+	virtual bool preStart();
 	virtual bool nextLine(const QString &line);
-
-private:
-	bool m_disable;
 };
 
 #endif // KGPGCHANGEDISABLE_H
