@@ -29,44 +29,45 @@
 // Qt
 #include <QtTest/QtTest>
 
-namespace KHEUI
+
+namespace Okteta
 {
 
 // local variables
-static const int NoOfBytesPerLine = 8;
-static const int StartOffset = 22;
-static const int FirstLineOffset = 10;
-static const int RelativeStartOffset = StartOffset-FirstLineOffset;
-static const int Length = 250;
-static const int FinalOffset = (StartOffset+Length-1);
-static const int RelativeFinalOffset = FinalOffset-FirstLineOffset;
+static const Size NoOfBytesPerLine = 8;
+static const Address StartOffset = 22;
+static const Address FirstLineOffset = 10;
+static const Address RelativeStartOffset = StartOffset-FirstLineOffset;
+static const Address ByteArrayOffset = 9;
+static const Size Length = 250;
+static const Address FinalOffset = (StartOffset+Length-1);
+static const Address RelativeFinalOffset = FinalOffset-FirstLineOffset;
 
-static const int FirstIndex = 0;
-static const int LastIndex = Length-1;
+static const Address FirstIndex = ByteArrayOffset;
+static const Address LastIndex = Length-1+ByteArrayOffset;
 
-static const int StartLine = RelativeStartOffset / NoOfBytesPerLine;
-static const int StartLinePosition = RelativeStartOffset % NoOfBytesPerLine;
+static const Line StartLine = RelativeStartOffset / NoOfBytesPerLine;
+static const LinePosition StartLinePosition = RelativeStartOffset % NoOfBytesPerLine;
 static Coord StartCoord( StartLinePosition, StartLine );
 
-static const int FinalLine =  RelativeFinalOffset/ NoOfBytesPerLine;
-static const int FinalLinePosition = RelativeFinalOffset % NoOfBytesPerLine;
+static const Line FinalLine =  RelativeFinalOffset/ NoOfBytesPerLine;
+static const LinePosition FinalLinePosition = RelativeFinalOffset % NoOfBytesPerLine;
 static Coord FinalCoord( FinalLinePosition, FinalLine );
 
-static const int NoOfLinesPerPage = 5;
+static const LineSize NoOfLinesPerPage = 5;
 
-static const int Pos1 = 15;
-static const int Pos2 = 25;
-static const int Line1 = 10;
-static const int LineSize = 10;
-static const int Line2 = Line1 + LineSize - 1;
+static const LinePosition Pos1 = 15;
+static const LinePosition Pos2 = 25;
+static const Line Line1 = 10;
+static const LineSize LineCount = 10;
+static const Line Line2 = Line1 + LineCount - 1;
 static Coord Start( Pos1, Line1 );
 static Coord End(   Pos2, Line2 );
 
 
 void ByteArrayTableCursorTest::testConstructor()
 {
-    const Coord StartCoord( 0, 0 );
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
@@ -87,7 +88,7 @@ void ByteArrayTableCursorTest::testConstructor()
 
 void ByteArrayTableCursorTest::testSetAppendPosEnabled()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
     const Coord finalCoord = layout.finalCoord();
 
     ByteArrayTableCursor cursor( &layout );
@@ -112,12 +113,12 @@ void ByteArrayTableCursorTest::testSetAppendPosEnabled()
 
 void ByteArrayTableCursorTest::testGotoIndex()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // 2 before first valid, as (in)validIndex equals -1, see next test
-    int index = FirstIndex-2;
+    Address index = FirstIndex-2;
     Coord coord = layout.coordOfIndex( index );
 
     cursor.gotoIndex( index );
@@ -221,12 +222,12 @@ void ByteArrayTableCursorTest::testGotoIndex()
 
 void ByteArrayTableCursorTest::testGotoCIndex()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // 2 before first valid, as (in)validIndex equals -1, see next test
-    int index = FirstIndex-2;
+    Address index = FirstIndex-2;
     const Coord startCoord = layout.startCoord();
 
     cursor.gotoCIndex( index );
@@ -328,12 +329,12 @@ void ByteArrayTableCursorTest::testGotoCIndex()
 
 void ByteArrayTableCursorTest::testGotoRealIndex()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // 2 before first valid, as (in)validIndex equals -1, see next test
-    int index = FirstIndex;
+    Address index = FirstIndex;
     Coord coord = layout.coordOfIndex( index );
     cursor.gotoIndex( index );
 
@@ -390,7 +391,7 @@ void ByteArrayTableCursorTest::testGotoRealIndex()
 
 void ByteArrayTableCursorTest::testGotoStart()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
     const Coord startCoord = layout.startCoord();
 
     ByteArrayTableCursor cursor( &layout );
@@ -408,7 +409,7 @@ void ByteArrayTableCursorTest::testGotoStart()
 
 void ByteArrayTableCursorTest::testGotoEnd()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
     const Coord finalCoord = layout.finalCoord();
 
     ByteArrayTableCursor cursor( &layout );
@@ -442,12 +443,12 @@ void ByteArrayTableCursorTest::testGotoEnd()
 
 void ByteArrayTableCursorTest::testGotoNextByte()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // at start
-    int index = FirstIndex + 1;
+    Address index = FirstIndex + 1;
     Coord coord = layout.startCoord();
     coord.goCRight( layout.noOfBytesPerLine()-1 );
     cursor.gotoStart();
@@ -526,13 +527,13 @@ void ByteArrayTableCursorTest::testGotoNextByte()
 
 void ByteArrayTableCursorTest::testGotoPreviousByte()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // at start
     cursor.gotoStart();
-    int index = cursor.index();
+    Address index = cursor.index();
     Coord coord = cursor.coord();
 
     cursor.gotoPreviousByte();
@@ -607,14 +608,14 @@ void ByteArrayTableCursorTest::testGotoPreviousByte()
 
 void ByteArrayTableCursorTest::testGotoNextByteN()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // at start
     // one right
-    int indexSteps = 1;
-    int expectedIndex = FirstIndex + indexSteps;
+    Address indexSteps = 1;
+    Address expectedIndex = FirstIndex + indexSteps;
     Coord expectedCoord = layout.coordOfIndex( expectedIndex );
     cursor.gotoStart();
 
@@ -836,13 +837,13 @@ void ByteArrayTableCursorTest::testGotoNextByteN()
 
 void ByteArrayTableCursorTest::testGotoPreviousByteN()
 {
-    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, Length );
+    const ByteArrayTableLayout layout( NoOfBytesPerLine, FirstLineOffset, StartOffset, ByteArrayOffset, Length );
 
     ByteArrayTableCursor cursor( &layout );
 
     // at start
-    int indexSteps = 1;
-    int expectedIndex = FirstIndex;
+    Address indexSteps = 1;
+    Address expectedIndex = FirstIndex;
     Coord expectedCoord = layout.coordOfIndex( expectedIndex );
     cursor.gotoStart();
 
@@ -982,4 +983,4 @@ void ByteArrayTableCursorTest::testGotoPreviousByteN()
 
 }
 
-QTEST_MAIN( KHEUI::ByteArrayTableCursorTest )
+QTEST_MAIN( Okteta::ByteArrayTableCursorTest )
